@@ -46,7 +46,8 @@ __all__ = [
     "PlotError",
     "OpponentError",
     "UsedRunnerError",
-    "NotEnoughAttentionBudget"
+    "NotEnoughAttentionBudget",
+    "AgentError"
 ]
 
 from grid2op.Exceptions.Grid2OpException import Grid2OpException
@@ -108,3 +109,5 @@ from grid2op.Exceptions.OpponentError import OpponentError
 from grid2op.Exceptions.RunnerError import UsedRunnerError
 
 from grid2op.Exceptions.AttentionBudgetExceptions import NotEnoughAttentionBudget
+
+from grid2op.Exceptions.agentError import AgentError
