@@ -199,10 +199,10 @@ class TestBasisObsBehaviour(unittest.TestCase):
                          "curtailment": [0.0, 0.0, 0.0, 0.0, 0.0],
                          "curtailment_limit": [1.0, 1.0, 1.0, 1.0, 1.0],
                          "theta_ex": [-1.3276801109313965, -4.100967884063721, -10.311812400817871, -11.245238304138184,
-                          -10.119081497192383, -10.50421142578125, -11.245238304138184, -4.473601341247559,
-                          -4.824699401855469, -4.100967884063721, -4.824699401855469, -4.100967884063721,
-                          -10.119081497192383, -10.39695930480957, -10.50421142578125, -7.88769006729126,
-                          -10.060456275939941, -9.613715171813965, -7.1114115715026855, -10.060456275939941],
+                                      -10.119081497192383, -10.50421142578125, -11.245238304138184, -4.473601341247559,
+                                      -4.824699401855469, -4.100967884063721, -4.824699401855469, -4.100967884063721,
+                                      -10.119081497192383, -10.39695930480957, -10.50421142578125, -7.88769006729126,
+                                      -10.060456275939941, -9.613715171813965, -7.1114115715026855, -10.060456275939941],
                          "theta_or": [0.0, 0.0, -10.060456275939941, -10.060456275939941, -10.311812400817871,
                                       -10.39695930480957, -10.50421142578125, -1.3276801109313965,
                                       -1.3276801109313965, -1.3276801109313965, -4.473601341247559,
@@ -226,7 +226,9 @@ class TestBasisObsBehaviour(unittest.TestCase):
                          "time_since_last_alarm": [-1],
                          "last_alarm": [],
                          "attention_budget": [0.],
-                         "was_alarm_used_after_game_over": [False]
+                         "was_alarm_used_after_game_over": [False],
+                         "current_step": [0],
+                         "max_step": [8064],
                          }
         self.dtypes = np.array([dt_int, dt_int, dt_int, dt_int,
                                 dt_int, dt_int, dt_float, dt_float,
@@ -244,16 +246,19 @@ class TestBasisObsBehaviour(unittest.TestCase):
                                 dt_bool, dt_int, dt_int, dt_float, dt_bool,
                                 # shunts
                                 dt_float, dt_float, dt_float, dt_int,
+                                # steps
+                                dt_int, dt_int
                                 ],
                                dtype=object)
 
         self.dtypes = np.array([np.dtype(el) for el in self.dtypes])
 
-        self.shapes = np.array([ 1,  1,  1,  1,  1,  1,  5,  5,  5, 11, 11, 11, 20, 20, 20, 20, 20,
-                                 20, 20, 20, 20, 20, 20, 56, 20, 14, 20, 20,
-                                 5, 5, 0, 0, 0, 5, 5, 5, 1, 1, 0, 1, 1,
-                                 1, 1, 1, 1,])
-        self.size_obs = 429 + 4 + 4
+        self.shapes = np.array([1,  1,  1,  1,  1,  1,  5,  5,  5, 11, 11, 11, 20, 20, 20, 20, 20,
+                                20, 20, 20, 20, 20, 20, 56, 20, 14, 20, 20,
+                                5, 5, 0, 0, 0, 5, 5, 5, 1, 1, 0, 1, 1,
+                                1, 1, 1, 1,
+                                1, 1])
+        self.size_obs = 429 + 4 + 4 + 2
 
     def tearDown(self):
         self.env.close()
