@@ -17,7 +17,7 @@ PATH_PREVIOUS_RUNNER = os.path.join(data_dir, "runner_data")
 
 import grid2op
 from grid2op.Chronics import Multifolder
-from grid2op.Reward import L2RPNReward
+from grid2op.Reward import L2RPNReward, N1Reward
 from grid2op.Backend import PandaPowerBackend
 from grid2op.MakeEnv import make
 from grid2op.Runner.aux_fun import _aux_one_process_parrallel
@@ -81,7 +81,7 @@ class TestRunner(HelperTests):
     def test_one_process_par(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            res = _aux_one_process_parrallel(self.runner, [0], 0, None, None, self.max_iter)
+            res = _aux_one_process_parrallel(self.runner, [0], 0, env_seeds=None, agent_seeds=None, max_iter=self.max_iter)
         assert len(res) == 1
         _, el1, el2, el3, el4 = res[0]
         assert el1 == "1"
@@ -100,6 +100,64 @@ class TestRunner(HelperTests):
             assert int(timestep) == self.max_iter
             assert np.abs(cum_reward - self.real_reward) <= self.tol_one
 
+    def test_2episode_2process_with_id(self):
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            res_1 = self.runner._run_parrallel(nb_episode=2,
+                                               nb_process=2,
+                                               episode_id=[0, 1],
+                                               max_iter=self.max_iter)
+        assert len(res_1) == 2
+        assert res_1[0][1] == '1'
+        assert res_1[1][1] == '2'
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            res_2 = self.runner._run_parrallel(nb_episode=2,
+                                               nb_process=2,
+                                               episode_id=[1, 0],
+                                               max_iter=self.max_iter)
+        assert len(res_2) == 2
+        assert res_2[0][1] == '2'
+        assert res_2[1][1] == '1'
+
+    def test_2episodes_with_id(self):
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            res_1 = self.runner.run(nb_episode=2,
+                                    episode_id=[0, 1],
+                                    max_iter=self.max_iter)
+        assert len(res_1) == 2
+        assert res_1[0][1] == '1'
+        assert res_1[1][1] == '2'
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            res_2 = self.runner.run(nb_episode=2,
+                                    episode_id=[1, 0],
+                                    max_iter=self.max_iter)
+        assert len(res_2) == 2
+        assert res_2[0][1] == '2'
+        assert res_2[1][1] == '1'
+
+    def test_2episodes_with_id_str(self):
+        env = self.runner.init_env()
+        subpaths = env.chronics_handler.subpaths
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            res_1 = self.runner.run(nb_episode=2,
+                                    episode_id=[subpaths[0], subpaths[1]],
+                                    max_iter=self.max_iter)
+        assert len(res_1) == 2
+        assert res_1[0][1] == '1'
+        assert res_1[1][1] == '2'
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            res_2 = self.runner.run(nb_episode=2,
+                                    episode_id=[subpaths[1], subpaths[0]],
+                                    max_iter=self.max_iter)
+        assert len(res_2) == 2
+        assert res_2[0][1] == '2'
+        assert res_2[1][1] == '1'
+
     def test_2episode_2process_detailed(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
@@ -316,6 +374,26 @@ class TestRunner(HelperTests):
             assert 'curtailment' in CompleteObservation.attr_list_vect, f"error after the legacy version " \
                                                                         f"{grid2op_version}"
 
+    def test_reward_as_object(self):
+        L_ID = 2
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            env = make("l2rpn_case14_sandbox", reward_class=N1Reward(l_id=L_ID), test=True)
+        runner = Runner(**env.get_params_for_runner())
+        runner.run(nb_episode=1, max_iter=10)
+        env.close()
+
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            env = grid2op.make("l2rpn_case14_sandbox",
+                                other_rewards={f"line_{l_id}": N1Reward(l_id=l_id)  for l_id in [0, 1]},
+                                test=True
+                                )
+
+        runner = Runner(**env.get_params_for_runner())
+        runner.run(nb_episode=1, max_iter=10)
+        env.close()
+        
 
 if __name__ == "__main__":
     unittest.main()
